build_gofer: Build a GOfER diagram (Graphical Overview for Evidence Reviews)
Description
It is recommended to set save = TRUE and indicate the path to save to, as the plot is not going to look good in the Plots panel.
Usage
build_gofer(page = c("1", "2"), save = FALSE, path, format = ".png")
Value
A patchwork object
Arguments
page
A text string to indicate the page you would like to display. This GOfER has two pages (28 studies in page 1 and 28 studies in page 2).
save
A boolean to indicate whether to save the plot to disk.
path
Path to write to. It has to be a character string indicating the path and file name (without the extension). For example, ~/Documents/metabolic_gofer_page_1 will save metabolic_gofer_page_1.png to the Documents folder.
format
The file extension that you want to save the plot to. Only .png, is supported.