Path to write to. It has to be a character string indicating the path and file name (without the extension). For example, ~/Documents/metabolic_report will save metabolic_report.html to the Documents folder.
format
The file extension that you want to build the report with. Only .html, is supported.